<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * Latvian, Lettish language file
 *
 * @author Oskars Pakers <oskars.pakers@gmail.com>
 * @author Aivars Miška <allefm@gmail.com>
 */
$lang['menu']                  = 'Konfigurācijas iestatījumi.';
$lang['error']                 = 'Iestatījumi nav saglabāti, jo uzdotas aplamas vērtības. Lūdzu pārskatīt izmaiņas un saglabāt atkārtoti.
<br /> Aplamās vērtības izceltas sarkanā rāmī.';
$lang['updated']               = 'Iestatījumi veiksmīgi saglabāti.';
$lang['nochoice']              = '(citu iespēju nav)';
$lang['locked']                = 'Iestatījumu fails nav grozāms, ja tā nevajag būt, <br />
pārliecinies, ka ir pareizs lokālo iestatījuma faila vārds un tiesības.';
$lang['danger']                = 'Bīstami: Šī parametra maiņa var padarīt wiki sistēmu un konfigurācijas izvēlni nepieejamu.';
$lang['warning']               = 'Brīdinājums: Šī parametra maiņa var izraisīt negaidītu programmas uzvedību.';
$lang['security']              = 'Drošības brīdinājums: Šī parametra maiņa var būt riskanta drošībai.';
$lang['_configuration_manager'] = 'Konfigurācijas pārvaldnieks';
$lang['_header_dokuwiki']      = 'Dokuwiki iestatījumi';
$lang['_header_plugin']        = 'Moduļu iestatījumi';
$lang['_header_template']      = 'Šablonu iestatījumi';
$lang['_header_undefined']     = 'Citi iestatījumi';
$lang['_basic']                = 'Pamatiestatījumi';
$lang['_display']              = 'Izskata iestatījumi';
$lang['_authentication']       = 'Autentifikācija';
$lang['_anti_spam']            = 'Pretspama iestatījumi';
$lang['_editing']              = 'Labošanas iestatījumi';
$lang['_links']                = 'Saišu iestatījumi';
$lang['_media']                = 'Mēdiju iestatījumi';
$lang['_notifications']        = 'Brīdinājumu iestatījumi';
$lang['_advanced']             = 'Smalkāka iestatīšana';
$lang['_network']              = 'Tīkla iestatījumi';
$lang['_msg_setting_undefined'] = 'Nav atrodami iestatījumu metadati';
$lang['_msg_setting_no_class'] = 'Nav iestatījumu klases';
$lang['_msg_setting_no_default'] = 'Nav noklusētās vērtības';
$lang['title']                 = 'Wiki virsraksts';
$lang['start']                 = 'Sākumlapas vārds';
$lang['lang']                  = 'Valoda';
$lang['template']              = 'Šablons';
$lang['license']               = 'Ar kādu licenci saturs tiks publicēts?';
$lang['savedir']               = 'Direktorija datu glabāšanai';
$lang['basedir']               = 'Saknes direktorija';
$lang['baseurl']               = 'Saknes adrese (URL)';
$lang['dmode']                 = 'Tiesības izveidotajām direktorijām';
$lang['fmode']                 = 'Tiesības izveidotajiem failiem';
$lang['allowdebug']            = 'Ieslēgt atkļūdošanu. <b>Izslēdz!</b>';
$lang['recent']                = 'Jaunākie grozījumi';
$lang['recent_days']           = 'Cik dienas glabāt jaunākās izmaiņas';
$lang['breadcrumbs']           = 'Apmeklējumu vēstures garums';
$lang['youarehere']            = 'Rādīt "tu atrodies šeit"';
$lang['fullpath']              = 'Norādīt kājenē pilnu lapas ceļu';
$lang['typography']            = 'Veikt tipogrāfijas aizvietošanu';
$lang['dformat']               = 'Datuma formāts (sk. PHP <a href="http://php.net/strftime">strftime</a> funkciju)';
$lang['signature']             = 'Paraksts';
$lang['showuseras']            = 'Kā rādīt pēdējo lietotāju, ka labojis lapu';
$lang['toptoclevel']           = 'Satura rādītāja pirmais līmenis';
$lang['tocminheads']           = 'Mazākais virsrakstu skaits, no kuriem jāveido satura rādītājs.';
$lang['maxtoclevel']           = 'Satura rādītāja dziļākais līmenis';
$lang['maxseclevel']           = 'Dziļākais sekciju labošanas līmenis';
$lang['camelcase']             = 'Lietot saitēm CamelCase';
$lang['deaccent']              = 'Lapu nosaukumu transliterācija';
$lang['useheading']            = 'Izmantot pirmo virsrakstu lapu nosaukumiem';
$lang['sneaky_index']          = 'Pēc noklusētā DokuWiki lapu sarakstā parāda visu nodaļu lapas. Ieslēdzot šo parametru, noslēps tās nodaļas, kuras apmeklētājam nav tiesības lasīt. Bet tad  tiks arī paslēptas dziļākas, bet atļautas nodaļas. Atsevišķos pieejas tiesību konfigurācijas gadījumos lapu saraksts var nedarboties.';
$lang['hidepages']             = 'Slēpt lapas (regulāras izteiksmes)';
$lang['useacl']                = 'Izmantot piekļuves tiesības';
$lang['autopasswd']            = 'Automātiski ģenerēt paroles';
$lang['authtype']              = 'Autentifikācijas mehānisms';
$lang['passcrypt']             = 'Paroļu šifrēšanas metode';
$lang['defaultgroup']          = 'Noklusētā grupa';
$lang['superuser']             = 'Administrators - grupa, lietotājs vai to saraksts ( piem.: user1,@group1,user2), kam ir pilnas tiesības.';
$lang['manager']               = 'Pārziņi - grupa, lietotājs vai to saraksts ( piem.: user1,@group1,user2), kam ir pieeja pie dažām administrēšanas funkcijām.';
$lang['profileconfirm']        = 'Profila labošanai vajag paroli';
$lang['rememberme']            = 'Atļaut pastāvīgas ielogošanās sīkdatnes ("atceries mani")';
$lang['disableactions']        = 'Bloķēt Dokuwiki darbības';
$lang['disableactions_check']  = 'atzīmēt';
$lang['disableactions_subscription'] = 'abonēt/atteikties';
$lang['disableactions_wikicode'] = 'skatīt/eksportēt izejtekstu';
$lang['disableactions_other']  = 'citas darbības (atdalīt ar komatiem)';
$lang['auth_security_timeout'] = 'Autorizācijas drošības intervāls (sekundēs)';
$lang['securecookie']          = 'Vai pa HTTPS sūtāmās sīkdatnes sūtīt tikai pa HTTPS? Atslēdz šo iespēju, kad tikai pieteikšanās wiki sistēmā notiek pa SSL šifrētu savienojumu, bet skatīšana  - pa nešifrētu.';
$lang['usewordblock']          = 'Bloķēt spamu pēc slikto vārdu saraksta.';
$lang['relnofollow']           = 'rel="nofollow" ārējām saitēm';
$lang['indexdelay']            = 'Laika aizture pirms indeksācijas (sekundēs)';
$lang['mailguard']             = 'Slēpt epasta adreses';
$lang['iexssprotect']          = 'Pārbaudīt, vai augšupielādētajā failā nav nav potenciāli bīstamā JavaScript vai HTML koda.';
$lang['usedraft']              = 'Labojot automātiski saglabāt melnrakstu';
$lang['htmlok']                = 'Atļaut iekļautu HTTP';
$lang['phpok']                 = 'Atļaut iekļautu PHP';
$lang['locktime']              = 'Bloķēšanas failu maksimālais vecums';
$lang['cachetime']             = 'Bufera maksimālais vecums (sek)';
$lang['target____wiki']        = 'Kur atvērt iekšējās saites';
$lang['target____interwiki']   = 'Kur atvērt saites strap wiki';
$lang['target____extern']      = 'Kur atvērt ārējās saites';
$lang['target____media']       = 'Kur atvērt mēdiju saites';
$lang['target____windows']     = 'Kur atvērt saites uz tīkla mapēm';
$lang['refcheck']              = 'Pārbaudīt saites uz mēdiju failiem';
$lang['gdlib']                 = 'GD Lib versija';
$lang['im_convert']            = 'Ceļš uz ImageMagick convert rīku';
$lang['jpg_quality']           = 'JPG saspiešanas kvalitāte';
$lang['fetchsize']             = 'Maksimālais faila apjoms baitos, ko fetch.php var ielādēt no interneta.';
$lang['subscribers']           = 'Atļaut abonēt izmaiņas';
$lang['subscribe_time']        = 'Pēc cik ilga laika izsūtīt abonētos sarakstus un kopsavilkumus (sekundes); jābūt mazākam par laiku, kas norādīts "recent_days".';
$lang['notify']                = 'Nosūtīt izmaiņu paziņojumu uz epasta adresi';
$lang['registernotify']        = 'Nosūtīt paziņojumu par jauniem lietotājiem uz epasta adresi';
$lang['mailfrom']              = 'Epasta adrese automātiskajiem paziņojumiem';
$lang['mailprefix']            = 'E-pasta temata prefikss automātiskajiem paziņojumiem';
$lang['sitemap']               = 'Lapas karte priekš Google (dienas)';
$lang['rss_type']              = 'XML barotnes veids';
$lang['rss_linkto']            = 'XML barotnes uz ';
$lang['rss_content']           = 'Ko attēlot XML barotnē?';
$lang['rss_update']            = 'XML barotnes atjaunošanas intervāls (sec)';
$lang['rss_show_summary']      = 'Rādīt visrakstos XML barotnes kopsavilkumu ';
$lang['updatecheck']           = 'Pārbaudīt, vai pieejami atjauninājumi un drošības brīdinājumi? Dokuwiki sazināsies ar update.dokuwiki.org';
$lang['userewrite']            = 'Ērti lasāmas adreses (URL)';
$lang['useslash']              = 'Lietot slīpiņu  par URL atdalītāju';
$lang['sepchar']               = 'Lapas nosaukuma vārdu atdalītājs';
$lang['canonical']             = 'Lietot kanoniskus URL';
$lang['fnencode']              = 'Ne ASCII failvārdu kodēšanas metode:';
$lang['autoplural']            = 'Automātisks daudzskaitlis';
$lang['compression']           = 'Saspiešanas metode vecajiem failiem';
$lang['gzip_output']           = 'Lietot gzip Content-Encoding priekš xhtml';
$lang['compress']              = 'Saspiest CSS un javascript failus';
$lang['send404']               = 'Par neesošām lapām atbildēt "HTTP 404/Page Not Found" ';
$lang['broken_iua']            = 'Varbūt tavā serverī nedarbojas funkcija ignore_user_abort? Tā dēļ var nestādāt meklēšanas indeksācija. Šī problēma sastopama, piemēram, IIS ar PHP/CGI. Papildus informāciju skatīt <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Kļūdā Nr.852</a>.';
$lang['xsendfile']             = 'Lietot X-Sendfile virsrakstu, augšupielādējot failu serverī? ';
$lang['renderer_xhtml']        = 'Galveno (xhtml) wiki saturu renderēt ar ';
$lang['renderer__core']        = '%s (dokuwiki kodols)';
$lang['renderer__plugin']      = '%s (modulis)';
$lang['proxy____host']         = 'Proxy servera vārds';
$lang['proxy____port']         = 'Proxy ports';
$lang['proxy____user']         = 'Proxy lietotāja vārds';
$lang['proxy____pass']         = 'Proxy parole';
$lang['proxy____ssl']          = 'Lietot SSL savienojumu ar proxy';
$lang['proxy____except']       = 'Regulārā izteiksme tiem URL, kam nevar lietot proxy.';
$lang['license_o_']            = 'Ar nekādu';
$lang['typography_o_0']        = 'neko';
$lang['typography_o_1']        = 'tikai dubultpēdiņas';
$lang['typography_o_2']        = 'visas pēdiņas (ne vienmēr strādā)';
$lang['userewrite_o_0']        = 'nē';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'DokuWiki līdzekļi';
$lang['deaccent_o_0']          = 'nē';
$lang['deaccent_o_1']          = 'atmest diakritiku';
$lang['deaccent_o_2']          = 'pārrakstīt latīņu burtiem';
$lang['gdlib_o_0']             = 'GD Lib nav pieejama';
$lang['gdlib_o_1']             = 'versija 1.x';
$lang['gdlib_o_2']             = 'noteikt automātiksi';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Abstract';
$lang['rss_content_o_diff']    = 'apvienotu diff';
$lang['rss_content_o_htmldiff'] = 'HTML formatētu diff tabulu';
$lang['rss_content_o_html']    = 'pilnu HTML lapas saturu';
$lang['rss_linkto_o_diff']     = 'atšķirības';
$lang['rss_linkto_o_page']     = 'grozītās lapas';
$lang['rss_linkto_o_rev']      = 'grozījumu sarakstu';
$lang['rss_linkto_o_current']  = 'patreizējo lapu';
$lang['compression_o_0']       = 'nav';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'nelietot';
$lang['xsendfile_o_1']         = 'lighttpd  (pirms laidiena 1.5) veida galvene';
$lang['xsendfile_o_2']         = 'Standarta X-Sendfile galvene';
$lang['xsendfile_o_3']         = 'Nginx X-Accel-Redirect veida galvene';
$lang['showuseras_o_loginname'] = 'Login vārds';
$lang['showuseras_o_username'] = 'Pilns lietotāja vārds';
$lang['showuseras_o_email']    = 'Lietotāja epasta adrese (slēpta ar norādīto paņēmienu)';
$lang['showuseras_o_email_link'] = 'Lietot epasta adreses kā mailto: saites';
$lang['useheading_o_0']        = 'Nekad';
$lang['useheading_o_navigation'] = 'Tikai navigācija';
$lang['useheading_o_content']  = 'Tikai Wiki saturs';
$lang['useheading_o_1']        = 'Vienmēr';
$lang['readdircache']          = 'Maksimālais readdir kesš dzīves laiks (sek.)';
